@@ -48,22 +48,30 @@ class MobioLogging:
         handler.setFormatter(LogstashFormatterV1())
         logging.basicConfig(handlers=[handler], level=logging.DEBUG)
 
-    @staticmethod
-    def warning(content, log_key=None):
-        content["log_key"] = log_key
-        logging.warning(content)
+    def warning(content):
+        self.logger.warning(content)
 
-    @staticmethod
-    def debug(content, log_key=None):
-        content["log_key"] = log_key
-        logging.debug(content)
+    def debug(content):
+        self.logger.warning(content)
 
-    @staticmethod
-    def error(content, log_key=None):
-        content["log_key"] = log_key
-        logging.error(content)
+    def error(content):
+        self.logger.warning(content)
 
-    @staticmethod
-    def info(content, log_key=None):
-        content["log_key"] = log_key
-        logging.info(content)
+    def info(content):
+        self.logger.warning(content)
+
+    # def warning(content, log_key=None):
+    #     content["log_key"] = log_key
+    #     logging.warning(content)
+
+    # def debug(content, log_key=None):
+    #     content["log_key"] = log_key
+    #     logging.debug(content)
+
+    # def error(content, log_key=None):
+    #     content["log_key"] = log_key
+    #     logging.error(content)
+
+    # def info(content, log_key=None):
+    #     content["log_key"] = log_key
+    #     logging.info(content)
